@@ -25,8 +25,8 @@
 //! > buckets in a `KBucketsTable` and hence is enforced by the public API
 //! > of the `KBucketsTable` and in particular the public `Entry` API.
 
-pub use crate::K_VALUE;
 use super::*;
+pub use crate::K_VALUE;
 
 /// A `PendingNode` is a `Node` that is pending insertion into a `KBucket`.
 #[derive(Debug, Clone)]
@@ -51,7 +51,7 @@ pub enum NodeStatus {
     /// The node is considered connected.
     Connected,
     /// The node is considered disconnected.
-    Disconnected
+    Disconnected,
 }
 
 impl<TKey, TVal> PendingNode<TKey, TVal> {
@@ -125,29 +125,29 @@ pub struct KBucket<TKey, TVal> {
     /// The timeout window before a new pending node is eligible for insertion,
     /// if the least-recently connected node is not updated as being connected
     /// in the meantime.
-    pending_timeout: Duration
+    pending_timeout: Duration,
 }
 
 /// The result of inserting an entry into a bucket.
 #[must_use]
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub enum InsertResult<TKey> {
-     /// The entry has been successfully inserted.
-     Inserted,
-     /// The entry is pending insertion because the relevant bucket is currently full.
-     /// The entry is inserted after a timeout elapsed, if the status of the
-     /// least-recently connected (and currently disconnected) node in the bucket
-     /// is not updated before the timeout expires.
-     Pending {
-         /// The key of the least-recently connected entry that is currently considered
-         /// disconnected and whose corresponding peer should be checked for connectivity
-         /// in order to prevent it from being evicted. If connectivity to the peer is
-         /// re-established, the corresponding entry should be updated with
-         /// [`NodeStatus::Connected`].
-         disconnected: TKey
-     },
-     /// The entry was not inserted because the relevant bucket is full.
-     Full
+    /// The entry has been successfully inserted.
+    Inserted,
+    /// The entry is pending insertion because the relevant bucket is currently full.
+    /// The entry is inserted after a timeout elapsed, if the status of the
+    /// least-recently connected (and currently disconnected) node in the bucket
+    /// is not updated before the timeout expires.
+    Pending {
+        /// The key of the least-recently connected entry that is currently considered
+        /// disconnected and whose corresponding peer should be checked for connectivity
+        /// in order to prevent it from being evicted. If connectivity to the peer is
+        /// re-established, the corresponding entry should be updated with
+        /// [`NodeStatus::Connected`].
+        disconnected: TKey,
+    },
+    /// The entry was not inserted because the relevant bucket is full.
+    Full,
 }
 
 /// The result of applying a pending node to a bucket, possibly
@@ -158,13 +158,13 @@ pub struct AppliedPending<TKey, TVal> {
     pub inserted: Node<TKey, TVal>,
     /// The node that has been evicted from the bucket to make room for the
     /// pending node, if any.
-    pub evicted: Option<Node<TKey, TVal>>
+    pub evicted: Option<Node<TKey, TVal>>,
 }
 
 impl<TKey, TVal> KBucket<TKey, TVal>
 where
     TKey: Clone + AsRef<KeyBytes>,
-    TVal: Clone
+    TVal: Clone,
 {
     /// Creates a new `KBucket` with the given timeout for pending entries.
     pub fn new(pending_timeout: Duration) -> Self {
@@ -189,7 +189,8 @@ where
     /// Returns a reference to the pending node of the bucket, if there is any
     /// with a matching key.
     pub fn as_pending(&self, key: &TKey) -> Option<&PendingNode<TKey, TVal>> {
-        self.pending().filter(|p| p.node.key.as_ref() == key.as_ref())
+        self.pending()
+            .filter(|p| p.node.key.as_ref() == key.as_ref())
     }
 
     /// Returns a reference to a node in the bucket.
@@ -199,7 +200,10 @@ where
 
     /// Returns an iterator over the nodes in the bucket, together with their status.
     pub fn iter(&self) -> impl Iterator<Item = (&Node<TKey, TVal>, NodeStatus)> {
-        self.nodes.iter().enumerate().map(move |(p, n)| (n, self.status(Position(p))))
+        self.nodes
+            .iter()
+            .enumerate()
+            .map(move |(p, n)| (n, self.status(Position(p))))
     }
 
     /// Inserts the pending node into the bucket, if its timeout has elapsed,
@@ -214,21 +218,20 @@ where
                 if self.nodes.is_full() {
                     if self.status(Position(0)) == NodeStatus::Connected {
                         // The bucket is full with connected nodes. Drop the pending node.
-                        return None
+                        return None;
                     }
                     debug_assert!(self.first_connected_pos.map_or(true, |p| p > 0)); // (*)
-                    // The pending node will be inserted.
+                                                                                     // The pending node will be inserted.
                     let inserted = pending.node.clone();
                     // A connected pending node goes at the end of the list for
                     // the connected peers, removing the least-recently connected.
                     if pending.status == NodeStatus::Connected {
                         let evicted = Some(self.nodes.remove(0));
-                        self.first_connected_pos = self.first_connected_pos
-                            .map_or_else(
-                                | | Some(self.nodes.len()),
-                                |p| p.checked_sub(1));
+                        self.first_connected_pos = self
+                            .first_connected_pos
+                            .map_or_else(|| Some(self.nodes.len()), |p| p.checked_sub(1));
                         self.nodes.push(pending.node);
-                        return Some(AppliedPending { inserted, evicted })
+                        return Some(AppliedPending { inserted, evicted });
                     }
                     // A disconnected pending node goes at the end of the list
                     // for the disconnected peers.
@@ -236,21 +239,25 @@ where
                         let insert_pos = p.checked_sub(1).expect("by (*)");
                         let evicted = Some(self.nodes.remove(0));
                         self.nodes.insert(insert_pos, pending.node);
-                        return Some(AppliedPending { inserted, evicted })
+                        return Some(AppliedPending { inserted, evicted });
                     } else {
                         // All nodes are disconnected. Insert the new node as the most
                         // recently disconnected, removing the least-recently disconnected.
                         let evicted = Some(self.nodes.remove(0));
                         self.nodes.push(pending.node);
-                        return Some(AppliedPending { inserted, evicted })
+                        return Some(AppliedPending { inserted, evicted });
                     }
                 } else {
                     // There is room in the bucket, so just insert the pending node.
                     let inserted = pending.node.clone();
                     match self.insert(pending.node, pending.status) {
-                        InsertResult::Inserted =>
-                            return Some(AppliedPending { inserted, evicted: None }),
-                        _ => unreachable!("Bucket is not full.")
+                        InsertResult::Inserted => {
+                            return Some(AppliedPending {
+                                inserted,
+                                evicted: None,
+                            })
+                        }
+                        _ => unreachable!("Bucket is not full."),
                     }
                 }
             } else {
@@ -289,8 +296,8 @@ where
             }
             // Reinsert the node with the desired status.
             match self.insert(node, status) {
-                InsertResult::Inserted => {},
-                _ => unreachable!("The node is removed before being (re)inserted.")
+                InsertResult::Inserted => {}
+                _ => unreachable!("The node is removed before being (re)inserted."),
             }
         }
     }
@@ -317,7 +324,7 @@ where
             NodeStatus::Connected => {
                 if self.nodes.is_full() {
                     if self.first_connected_pos == Some(0) || self.pending.is_some() {
-                        return InsertResult::Full
+                        return InsertResult::Full;
                     } else {
                         self.pending = Some(PendingNode {
                             node,
@@ -325,8 +332,8 @@ where
                             replace: Instant::now() + self.pending_timeout,
                         });
                         return InsertResult::Pending {
-                            disconnected: self.nodes[0].key.clone()
-                        }
+                            disconnected: self.nodes[0].key.clone(),
+                        };
                     }
                 }
                 let pos = self.nodes.len();
@@ -336,7 +343,7 @@ where
             }
             NodeStatus::Disconnected => {
                 if self.nodes.is_full() {
-                    return InsertResult::Full
+                    return InsertResult::Full;
                 }
                 if let Some(ref mut p) = self.first_connected_pos {
                     self.nodes.insert(*p, node);
@@ -357,17 +364,19 @@ where
             let node = self.nodes.remove(pos.0);
             // Adjust `first_connected_pos` accordingly.
             match status {
-                NodeStatus::Connected =>
+                NodeStatus::Connected => {
                     if self.first_connected_pos.map_or(false, |p| p == pos.0) {
                         if pos.0 == self.nodes.len() {
                             // It was the last connected node.
                             self.first_connected_pos = None
                         }
                     }
-                NodeStatus::Disconnected =>
+                }
+                NodeStatus::Disconnected => {
                     if let Some(ref mut p) = self.first_connected_pos {
                         *p -= 1;
                     }
+                }
             }
             Some((node, status, pos))
         } else {
@@ -406,7 +415,10 @@ where
 
     /// Gets the position of an node in the bucket.
     pub fn position(&self, key: &TKey) -> Option<Position> {
-        self.nodes.iter().position(|p| p.key.as_ref() == key.as_ref()).map(Position)
+        self.nodes
+            .iter()
+            .position(|p| p.key.as_ref() == key.as_ref())
+            .map(Position)
     }
 
     /// Gets a mutable reference to the node identified by the given key.
@@ -414,30 +426,35 @@ where
     /// Returns `None` if the given key does not refer to a node in the
     /// bucket.
     pub fn get_mut(&mut self, key: &TKey) -> Option<&mut Node<TKey, TVal>> {
-        self.nodes.iter_mut().find(move |p| p.key.as_ref() == key.as_ref())
+        self.nodes
+            .iter_mut()
+            .find(move |p| p.key.as_ref() == key.as_ref())
     }
 }
 
 #[cfg(test)]
 mod tests {
+    use super::*;
     use libp2p_core::PeerId;
+    use quickcheck::*;
     use rand::Rng;
     use std::collections::VecDeque;
-    use super::*;
-    use quickcheck::*;
 
     impl Arbitrary for KBucket<Key<PeerId>, ()> {
         fn arbitrary<G: Gen>(g: &mut G) -> KBucket<Key<PeerId>, ()> {
             let timeout = Duration::from_secs(g.gen_range(1, g.size() as u64));
             let mut bucket = KBucket::<Key<PeerId>, ()>::new(timeout);
             let num_nodes = g.gen_range(1, K_VALUE.get() + 1);
-            for _ in 0 .. num_nodes {
+            for _ in 0..num_nodes {
                 let key = Key::from(PeerId::random());
-                let node = Node { key: key.clone(), value: () };
+                let node = Node {
+                    key: key.clone(),
+                    value: (),
+                };
                 let status = NodeStatus::arbitrary(g);
                 match bucket.insert(node, status) {
                     InsertResult::Inserted => {}
-                    _ => panic!()
+                    _ => panic!(),
                 }
             }
             bucket
@@ -463,7 +480,7 @@ mod tests {
     // Fill a bucket with random nodes with the given status.
     fn fill_bucket(bucket: &mut KBucket<Key<PeerId>, ()>, status: NodeStatus) {
         let num_entries_start = bucket.num_entries();
-        for i in 0 .. K_VALUE.get() - num_entries_start {
+        for i in 0..K_VALUE.get() - num_entries_start {
             let key = Key::from(PeerId::random());
             let node = Node { key, value: () };
             assert_eq!(InsertResult::Inserted, bucket.insert(node, status));
@@ -483,13 +500,16 @@ mod tests {
             // Fill the bucket, thereby populating the expected lists in insertion order.
             for status in status {
                 let key = Key::from(PeerId::random());
-                let node = Node { key: key.clone(), value: () };
+                let node = Node {
+                    key: key.clone(),
+                    value: (),
+                };
                 let full = bucket.num_entries() == K_VALUE.get();
                 match bucket.insert(node, status) {
                     InsertResult::Inserted => {
                         let vec = match status {
                             NodeStatus::Connected => &mut connected,
-                            NodeStatus::Disconnected => &mut disconnected
+                            NodeStatus::Disconnected => &mut disconnected,
                         };
                         if full {
                             vec.pop_front();
@@ -501,21 +521,20 @@ mod tests {
             }
 
             // Get all nodes from the bucket, together with their status.
-            let mut nodes = bucket.iter()
+            let mut nodes = bucket
+                .iter()
                 .map(|(n, s)| (s, n.key.clone()))
                 .collect::<Vec<_>>();
 
             // Split the list of nodes at the first connected node.
-            let first_connected_pos = nodes.iter().position(|(s,_)| *s == NodeStatus::Connected);
+            let first_connected_pos = nodes.iter().position(|(s, _)| *s == NodeStatus::Connected);
             assert_eq!(bucket.first_connected_pos, first_connected_pos);
             let tail = first_connected_pos.map_or(Vec::new(), |p| nodes.split_off(p));
 
             // All nodes before the first connected node must be disconnected and
             // in insertion order. Similarly, all remaining nodes must be connected
             // and in insertion order.
-            nodes == Vec::from(disconnected)
-                &&
-            tail == Vec::from(connected)
+            nodes == Vec::from(disconnected) && tail == Vec::from(connected)
         }
 
         quickcheck(prop as fn(_) -> _);
@@ -532,12 +551,12 @@ mod tests {
         let key = Key::from(PeerId::random());
         let node = Node { key, value: () };
         match bucket.insert(node, NodeStatus::Disconnected) {
-            InsertResult::Full => {},
-            x => panic!("{:?}", x)
+            InsertResult::Full => {}
+            x => panic!("{:?}", x),
         }
 
         // One-by-one fill the bucket with connected nodes, replacing the disconnected ones.
-        for i in 0 .. K_VALUE.get() {
+        for i in 0..K_VALUE.get() {
             let (first, first_status) = bucket.iter().next().unwrap();
             let first_disconnected = first.clone();
             assert_eq!(first_status, NodeStatus::Disconnected);
@@ -545,17 +564,21 @@ mod tests {
             // Add a connected node, which is expected to be pending, scheduled to
             // replace the first (i.e. least-recently connected) node.
             let key = Key::from(PeerId::random());
-            let node = Node { key: key.clone(), value: () };
+            let node = Node {
+                key: key.clone(),
+                value: (),
+            };
             match bucket.insert(node.clone(), NodeStatus::Connected) {
-                InsertResult::Pending { disconnected } =>
-                    assert_eq!(disconnected, first_disconnected.key),
-                x => panic!("{:?}", x)
+                InsertResult::Pending { disconnected } => {
+                    assert_eq!(disconnected, first_disconnected.key)
+                }
+                x => panic!("{:?}", x),
             }
 
             // Trying to insert another connected node fails.
             match bucket.insert(node.clone(), NodeStatus::Connected) {
-                InsertResult::Full => {},
-                x => panic!("{:?}", x)
+                InsertResult::Full => {}
+                x => panic!("{:?}", x),
             }
 
             assert!(bucket.pending().is_some());
@@ -564,10 +587,13 @@ mod tests {
             let pending = bucket.pending_mut().expect("No pending node.");
             pending.set_ready_at(Instant::now() - Duration::from_secs(1));
             let result = bucket.apply_pending();
-            assert_eq!(result, Some(AppliedPending {
-                inserted: node.clone(),
-                evicted: Some(first_disconnected)
-            }));
+            assert_eq!(
+                result,
+                Some(AppliedPending {
+                    inserted: node.clone(),
+                    evicted: Some(first_disconnected)
+                })
+            );
             assert_eq!(Some((&node, NodeStatus::Connected)), bucket.iter().last());
             assert!(bucket.pending().is_none());
             assert_eq!(Some(K_VALUE.get() - (i + 1)), bucket.first_connected_pos);
@@ -580,8 +606,8 @@ mod tests {
         let key = Key::from(PeerId::random());
         let node = Node { key, value: () };
         match bucket.insert(node, NodeStatus::Connected) {
-            InsertResult::Full => {},
-            x => panic!("{:?}", x)
+            InsertResult::Full => {}
+            x => panic!("{:?}", x),
         }
     }
 
@@ -594,7 +620,10 @@ mod tests {
 
         // Add a connected pending node.
         let key = Key::from(PeerId::random());
-        let node = Node { key: key.clone(), value: () };
+        let node = Node {
+            key: key.clone(),
+            value: (),
+        };
         if let InsertResult::Pending { disconnected } = bucket.insert(node, NodeStatus::Connected) {
             assert_eq!(&disconnected, &first_disconnected.key);
         } else {
@@ -607,16 +636,21 @@ mod tests {
 
         // The pending node has been discarded.
         assert!(bucket.pending().is_none());
-        assert!(bucket.iter().all(|(n,_)| &n.key != &key));
+        assert!(bucket.iter().all(|(n, _)| &n.key != &key));
 
         // The initially disconnected node is now the most-recently connected.
-        assert_eq!(Some((&first_disconnected, NodeStatus::Connected)), bucket.iter().last());
-        assert_eq!(bucket.position(&first_disconnected.key).map(|p| p.0), bucket.first_connected_pos);
+        assert_eq!(
+            Some((&first_disconnected, NodeStatus::Connected)),
+            bucket.iter().last()
+        );
+        assert_eq!(
+            bucket.position(&first_disconnected.key).map(|p| p.0),
+            bucket.first_connected_pos
+        );
         assert_eq!(1, bucket.num_connected());
         assert_eq!(K_VALUE.get() - 1, bucket.num_disconnected());
     }
 
-
     #[test]
     fn bucket_update() {
         fn prop(mut bucket: KBucket<Key<PeerId>, ()>, pos: Position, status: NodeStatus) -> bool {
@@ -627,7 +661,10 @@ mod tests {
             let key = bucket.nodes[pos].key.clone();
 
             // Record the (ordered) list of status of all nodes in the bucket.
-            let mut expected = bucket.iter().map(|(n,s)| (n.key.clone(), s)).collect::<Vec<_>>();
+            let mut expected = bucket
+                .iter()
+                .map(|(n, s)| (n.key.clone(), s))
+                .collect::<Vec<_>>();
 
             // Update the node in the bucket.
             bucket.update(&key, status);
@@ -636,14 +673,17 @@ mod tests {
             // preserving the status and relative order of all other nodes.
             let expected_pos = match status {
                 NodeStatus::Connected => num_nodes - 1,
-                NodeStatus::Disconnected => bucket.first_connected_pos.unwrap_or(num_nodes) - 1
+                NodeStatus::Disconnected => bucket.first_connected_pos.unwrap_or(num_nodes) - 1,
             };
             expected.remove(pos);
             expected.insert(expected_pos, (key.clone(), status));
-            let actual = bucket.iter().map(|(n,s)| (n.key.clone(), s)).collect::<Vec<_>>();
+            let actual = bucket
+                .iter()
+                .map(|(n, s)| (n.key.clone(), s))
+                .collect::<Vec<_>>();
             expected == actual
         }
 
-        quickcheck(prop as fn(_,_,_) -> _);
+        quickcheck(prop as fn(_, _, _) -> _);
     }
 }
